@@ -307,8 +307,8 @@ void signal_handler(int sig)
 			do_exit();
 			break;
 	
-		case SIGHUP:
-			got_sighup = 1;
+		case SIGUSR1:
+			got_sigusr1 = 1;
 			break;
 
 		case SIGWINCH:
@@ -2271,7 +2271,7 @@ int main(int argc, char *argv[])
 	start_all_processes(nsubwindows);
 	myfree(nsubwindows);
 
-	signal(SIGHUP, signal_handler);
+	signal(SIGUSR1, signal_handler);
 
 	main_loop();
 
@@ -2281,7 +2281,7 @@ int main(int argc, char *argv[])
 	return 0;
 }
 
-void sighup_restart_tails(void)
+void sigusr1_restart_tails(void)
 {
 	int f_index;
 
@@ -2297,14 +2297,14 @@ void sighup_restart_tails(void)
 
 				stop_process(cur -> pid);
 
-				if (myclose(cur -> fd) == -1) error_exit("sighup_restart_tails: closing read filedescriptor failed\n");
+				if (myclose(cur -> fd) == -1) error_exit("sigusr1_restart_tails: closing read filedescriptor failed\n");
 				if (cur -> fd != cur -> wfd)
 				{
-					if (myclose(cur -> wfd) == -1) error_exit("sighup_restart_tails: closing write filedescriptor failed\n");
+					if (myclose(cur -> wfd) == -1) error_exit("sigusr1_restart_tails: closing write filedescriptor failed\n");
 				}
 
 				/* create a pipe, will be to child-process */
-				if (-1 == pipe(pipefd)) error_exit("sighup_restart_tails: error creating pipe\n");
+				if (-1 == pipe(pipefd)) error_exit("sigusr1_restart_tails: error creating pipe\n");
 
 				cur -> pid = start_tail(cur -> filename, cur -> retry_open, cur -> follow_filename, min_n_bufferlines, pipefd);
 				cur -> fd = pipefd[0];
@@ -2626,9 +2626,9 @@ int wait_for_keypress(int what_help, double max_wait, NEWWIN *popup, char cursor
 		 */
 		check_exited_children();
 
-		if (got_sighup)
+		if (got_sigusr1)
 		{
-			sighup_restart_tails();
+			sigusr1_restart_tails();
 		}
 
 		/* any key pressed? */
