@@ -41,7 +41,7 @@
 #endif
 #if defined(AIX)
 #endif
-#if defined(hpux) || defined(__hpux)
+#if defined(_HPUX_SOURCE)
 #include <sys/stream.h>
 #include <sys/stropts.h>
 #include <sys/termios.h>
@@ -85,7 +85,7 @@ int get_pty_and_fork(int *fd_master, int *fd_slave)
 
 	return fork();
 
-#elif defined(sun) || defined(__sun) || defined(AIX) || defined(hpux) || defined(__hpux) || defined(OSF1) || defined(scoos)
+#elif defined(sun) || defined(__sun) || defined(AIX) || defined(_HPUX_SOURCE) || defined(OSF1) || defined(scoos)
 
 	/*
 	 * This code is used e.g. on Solaris 2.x.  (Note that Solaris 2.3
